Learn R Programming

flowWorkspace (version 3.12.06)

GatingSet,character,character-method: constructors for GatingSet

Description

construct object from xml workspace file and a list of sampleIDs (not intended to be called by user.)

construct a gatingset with empty trees (just root node)

construct object from existing gating hierarchy(gating template) and flow data

Usage

"GatingSet"(x, y, includeGates = FALSE, sampNloc = "keyword", xmlParserOption, wsType)
"GatingSet"(x)
"GatingSet"(x, y, path = ".", isNcdf = FALSE, ...)

Arguments

x
character or flowSet or GatingHierarchy
y
character ormissing
includeGates
logical whether to parse the gates or just simply extract the flowJo stats
sampNloc
character scalar indicating where to get sampleName(or FCS filename) within xml workspace. It is either from "keyword" or "sampleNode".
xmlParserOption
integer option passed to xmlTreeParse
wsType
character workspace type, can be value of "win", "macII", "vX", "macIII".
path
character specifies the path to the flow data (FCS files)
isNcdf
logical whether to use ncdfFlowSet or flowSet as the underlying flow data storage
...
other arguments. see parseWorkspace

Examples

Run this code
## Not run: 
# #fdata could be a flowSet or ncdfFlowSet
# gs <- GatingSet(fdata)
# ## End(Not run)

Run the code above in your browser using DataLab