Learn R Programming

flowWorkspace (version 3.12.06)

getSample,GatingHierarchy-method: Get the sample name associated with a GatingHierarchy

Description

Return the sample name

Usage

"getSample"(x, isFullPath = FALSE)

Arguments

x
A GatingHierarchy
isFullPath
isFullPath is a logical value indicating whether the full path of the sample FCS file is returned.Default is FALSE.

Value

A "character" vector of length 1. Either the sample name or the path to the FCS file.

Details

Returns the name of the sample, or the path to the FCS file.

Examples

Run this code
## Not run: 
#     #G is  a GatingHierarhcy
#     getSample(G)
#   ## End(Not run)

Run the code above in your browser using DataLab