Learn R Programming

flowWorkspace (version 3.12.06)

getSingleCellExpression,GatingSet,character-method: Return the cell events data that express in any of the single populations defined in y

Description

Returns a list of matrix containing the events that expressed in any one of the populations efined in y

Usage

"getSingleCellExpression"(x, nodes, map = NULL, swap = FALSE, threshold = TRUE)
"getSingleCellExpression"(x, nodes, ...)

Arguments

x
A GatingSet or GatingSetList object .
nodes
character vector specifying different cell populations
map
mapping node names (as specified in the gating hierarchy of the gating set) to channel names (as specified in either the desc or name columns of the parameters of the associated flowFrames in the GatingSet).
swap
logical indicates whether channels and markers of flow data are swapped.
threshold
logical indicates whether to threshold the flow data by setting intensity value to zero when it is below the gate threshold.
...
other arguments

Value

A list of numerci matrices

See Also

getIndices getPopStats

Examples

Run this code
## Not run: 
#   #G is a GatingSet
# 	geData(G,3)
# 	res <- getSingleCellExpression(gs[1], c("4+/TNFa+", "4+/IL2+"))
# 	res[[1]]
# 	res <- getSingleCellExpression(gs[1], c("4+/TNFa+", "4+/IL2+") , list("4+/TNFa+" = "TNFa", "4+/IL2+" = "IL2"))
# ## End(Not run)

Run the code above in your browser using DataLab