Learn R Programming

flowWorkspace (version 3.12.06)

isNcdf: determine the flow data associated with a Gating Hiearchy is based on `ncdfFlowSet` or `flowSet`

Description

determine the flow data associated with a Gating Hiearchy is based on `ncdfFlowSet` or `flowSet`

Usage

isNcdf(x)

Arguments

x
GatingHiearchy object

Value

logical